upoints.kml

Package upoints :: Module kml |
[hide private]
[frames] | no frames]

# Module kml

kml - Imports KML data files

Classes | [hide private]
| Placemark Class for representing a Placemark element from KML data files
| Placemarks Class for representing a group of Placemark objects

Functions | [hide private]
`function` |
create_elem(tag, attr=None, kml_version=`'``2.2``'`, human_namespace=False) Create a partial `ET.Element` wrapper with namespace defined |

Variables | [hide private]
| KML_VERSIONS = ``{``'``2.0``'``:` `'``http://earth.google.com/kml/2.0``'``,` `'``2.1``...`` Supported KML namespace version to URI mapping
| DEF_KML_VERSION = ``'``2.2``'`` Default KML version to output

Function Details | [hide private]

### create_elem(tag, attr=None, kml_version=`'``2.2``'`, human_namespace=False) |
Create a partial `ET.Element` wrapper with namespace defined Parameters: `tag` (`str`) - Tag name `attr` (`dict`) - Default attributes for tag `kml_version` (`str`) - KML version to use `human_namespace` (`bool`) - Whether to generate output using human readable namespace prefixes Returns: `function` `ET.Element` wrapper with predefined namespace

Variables Details | [hide private]

  ### KML_VERSIONS Supported KML namespace version to URI mapping Value:
      {'2.0': 'http://earth.google.com/kml/2.0',
       '2.1': 'http://earth.google.com/kml/2.1',
       '2.2': 'http://earth.google.com/kml/2.2'}